@@ -22,6 +22,10 @@ class Path:
     def has_suffix(self):
         return self.pathlib.suffix != ''
 
+    @property
+    def exists(self):
+        return self.pathlib.exists()
+
     @property
     def is_file_like(self):
 
